<?php
/*
Plugin Name: Covert Copy Traffic
Description: This plugin allows you to automatically insert links and text when people copy and paste your blog content. Copy and pasting is still the number 1 method for social sharing and with this plugin you finally get to reap the traffic and backlinks from it. <a href="http://coverttrafficcopy.com" target="_blank">Click here to upgrade to the Pro version</a>
Version: 1.1
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins

Copyright 2012  IM Wealth Builders

*/

define('IMWB_CPY_VERSION', '1.1');
define('IMWB_CPY_FOLDER', 'covertcopytraffic');
define('IMWB_CPY_PREFIX', 'imwb_');

/**
 * This is where you add comments for your plugin class 
 * @author John Merrick
 */
class IMWB_Covert_Copy {
	/**
	 * This value will be used for 
	 * - the gettext textdomain 
	 * - the subfolder when adding scripts and styles
	 * - the handle for scripts and styles
	 * Please make sure that this value corresponds to the folder name where your plugin resides.
	 * @var string 
	 */
	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $update;
		
	/**
	 * The constructor is executed when the class is instatiated and the plugin gets loaded.
	 * @return void
	 */
	function IMWB_Covert_Copy() {
	
	   $this->plugin_name = IMWB_CPY_PREFIX.IMWB_CPY_FOLDER;
	
   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

   	$this->plugin_url = plugins_url(basename( dirname( __FILE__)));
		
      if(is_admin()){
         // Get Update Information
      	$this->get_update_info();
     		add_action('after_plugin_row', array(&$this, 'check_for_update'));
      	add_action('admin_menu', array(&$this,'init_admin_menu'));
 			add_action('init', array(&$this, 'init_styles'), 20);
      }
      else {
      	add_action('wp_print_scripts', array(&$this, 'init_scripts'),20);
      }
      
	}
	
	//Returns an array of admin options
	function get_admin_options() {
		$adminOptions = array('aText' => 'Read More',
		                      'aURL' => 'P',
		                      'aURLCustom' => '',
		                      'aPlace' => 'B',
		                      'aMinWords' => '10');
			
		$devOptions = get_option($this->plugin_name."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}				
		update_option($this->plugin_name."-AdminOptions", $adminOptions);
		return $adminOptions;
	}
	
	/**
	 * Loading the frontend javascripts
	 * /scripts/script.js from the plugin directory. By default the script is enqueued 
	 * in the page footer for faster page loading. 
	 * @return void
	 */
	function init_scripts() {
   	$devOptions = $this->get_admin_options();
   	
		// Only enqueue scripts on frontend. 
		wp_enqueue_script('jquery');
      wp_enqueue_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/script.js', array('jquery'), IMWB_CPY_VERSION);
      
      $aURL = '';
      
      switch($devOptions['aURL']) {
         case 'P': $aURL =  "http://" . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
                   break;
         case 'H': $aURL = home_url();
                   break;
         case 'C': $aURL = $devOptions['aURLCustom'];
                   break;
      }
      
      if(!empty($aURL))
         $aURL = "<a href='".$aURL."'>".$aURL."</a>";
      
    	wp_localize_script( $this->plugin_name . '-script', 'IMWB_CPY_Options', array( 'aText' => esc_attr($devOptions['aText']).' '.$aURL, 'aPlace' => $devOptions['aPlace'], 'aMinWords' =>  $devOptions['aMinWords']) );
	}
		
	/**
	 * Loading the stylesheet for this plugin. 
	 * @return void
	 */
	function init_styles() {
      wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/admin_options_page.css', array(), '1.1', 'all');
	}
	
	/**
	 * Adds a new menu with the name "My Admin Menu" and let's anyone that
	 * can publish posts be able to use it. 
	 * @return void
	 */
	function init_admin_menu() {
		// Add the menu page
		add_options_page('Covert Copy Traffic Admin Menu', 'Covert Copy Traffic', 'manage_options', $this->plugin_name . '-admin-menu', array(&$this,'main_menu_page'));
	}

	/**
	 * This function will be executed when the admin page is to be loaded
	 * @return void
	 */
	function main_menu_page() {
		$devOptions = $this->get_admin_options();
		// Include the HTML from a separate file to keep the plugin class clean
		require "pages/admin_options_page.php";
	}
	
	function get_wp_root_path()
	{
	    $path = parse_url(get_bloginfo('wpurl'), PHP_URL_PATH);
	    if(!isset($path))
	       return '/';
	    else
	  	    return $path;
	}
	
	function get_update_info() {
      // Include Update Class
      require_once('covertcopy-admin-update.php');
      
      // Initialize Update Object
      $this->update = new IMWB_Covert_CopyUpdate($this->plugin_name);	
	}
	
	function check_for_update($plugin)
	{
      if(strpos($plugin, IMWB_CPY_FOLDER.'/') !== false) {
      	if(!$this->update->getUpdateInfo(1))
      	   echo '<tr class="plugin-update-tr"><td colspan="3" class="plugin-update"><div class="update-message">Warning: Could Not Connect To Covert Copy Traffic Update Server</td></tr>';
      }			
	}
	
}

/**
 * Register the plugin
 * @todo Change 'Plugin_Boilerplate' in the anonymous function to the name of the class
 */
add_action("init", create_function('', 'new IMWB_Covert_Copy();'));
